<?php
/**
 * @package XML_Sitemaps
 */
header("Content-Type: text/xml");
header('Access-Control-Allow-Origin: *');
echo '<?xml version="1.0" encoding="UTF-8"?>';
?><xsl:stylesheet version="2.0"
                xmlns:html="http://www.w3.org/TR/REC-html40"
				xmlns:image="http://www.google.com/schemas/sitemap-image/1.1"
                xmlns:sitemap="http://www.sitemaps.org/schemas/sitemap/0.9"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:video="http://www.google.com/schemas/sitemap-video/1.1">
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>XML Sitemap</title>
				<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
				<style type="text/css">
					body {
						font-family: Helvetica, Arial, sans-serif;
						font-size: 13px;
						color: #545353;
					}
					div#sitemap{
					    display: block;
					    width: 100%;
					    max-width: 1000px;
					}
					.sitemap-header{
					    border-bottom: 2px solid #000;
					}
					.header-value{
					    display: block;
					    font-size: 14px;
					    font-weight: bold;
					    text-indent: 6px;
					}
					.sitemap-body{
					    display: block;
					    overflow: hidden;
					    clear: both;
					    float: none;
					}
					.body-value{
					    display: block;
					    overflow: hidden;
					    float: none;
					    clear: both;
					    margin: 5px 0;
					    border-bottom: 1px solid #000;
					    padding: 0 0 5px 0;
					}
					.value-left{
					    display: block;
					    float: left;
					    overflow: hidden;
					    width: 25%;
					    text-align: center;
					}
					.value-left img{
					    width: 75%;
					    margin: 0 auto;
					}
					.value-right{
					    display: block;
					    float: right;
					    overflow: hidden;
					    width: 75%;
					}
					.inner-value{
					    display: block;
					    border-bottom: 1px solid #000;
					    margin: 0 0 5px 0;
					}
					.inner-value:last-child{
					    border: none;
					}
					.inner-value span{
					    font-weight: bold;
					}
					.inner-value a{
						color: #da3114;
					}
					.inner-value a:visited{
						color: #da3114;
					}
					
			
					#content {
						margin: 0 auto;
						width: 1000px;
					}
					.expl {
						margin: 18px 3px;
						line-height: 1.2em;
					}
					.expl a {
						color: #da3114;
						font-weight: bold;
					}
					.expl a:visited {
						color: #da3114;
					}
					a {
						color: #000;
						text-decoration: none;
					}
					a:visited {
						color: #777;
					}
					a:hover {
						text-decoration: underline;
					}
					
				</style>
			</head>
			<body>
				<div id="content">
					<h1>XML Sitemap</h1>
					<p class="expl">
						Generated by <a href="http://dealertrend.com/">DealerTrend</a>'s <a href="http://dealertrend.com/">Inventory API plugin</a>, this is an XML Sitemap, meant for consumption by search engines.<br/>
						You can find more information about XML sitemaps on <a href="http://sitemaps.org">sitemaps.org</a>.
					</p>
					
					<xsl:if test="count(sitemap:sitemapindex/sitemap:sitemap) &lt; 1">
						<p class="expl">
							This XML Sitemap contains <xsl:value-of select="count(sitemap:urlset/sitemap:url)"/> URLs.
						</p>
						<div id="sitemap" class="sitemap-container">
							<div class="sitemap-header">
								<div class="header-value">Available Videos</div>
							</div>
							<div class="sitemap-body">
								<xsl:variable name="lower" select="'abcdefghijklmnopqrstuvwxyz'"/>
								<xsl:variable name="upper" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
								<xsl:for-each select="sitemap:urlset/sitemap:url">
								
									<div class="body-value">
										<div class="value-left">
											<xsl:variable name="itemImage">
												<xsl:value-of select="video:video/video:thumbnail_loc"/>
											</xsl:variable>
											<img src="{$itemImage}" />
										</div>
										<div class="value-right">
											<div class="value-inner">
												<div class="inner-value">
													<span><xsl:value-of select="video:video/video:title"/></span>
												</div>
												<div class="inner-value">
													<xsl:variable name="itemURL">
														<xsl:value-of select="sitemap:loc"/>
													</xsl:variable>
													<span>URL: </span> <a href="{$itemURL}" target="_blank"><xsl:value-of select="sitemap:loc"/></a>
												</div>
												<div class="inner-value">
													<xsl:value-of select="video:video/video:description"/>
												</div>
												<div class="inner-value">
													<xsl:variable name="itemVideo">
														<xsl:value-of select="video:video/video:player_loc"/>
													</xsl:variable>
													<span>Video: </span> <a href="{$itemVideo}" target="_blank"><xsl:value-of select="video:video/video:player_loc"/></a>
												</div>
											</div>
										</div>
									</div>
									
								</xsl:for-each>
							</div>
						</div>
					</xsl:if>
				</div>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>